@@ -43,9 +43,9 @@ import subprocess
 import re
 import logging
 import natlink
-from natlink import natlinkutils
+from natlinkcore import natlinkutils
 import VocolaUtils
-import natlinkvocolastartup  # was natlinkstartup in natlinkmain...
+# import natlinkvocolastartup  # was natlinkstartup in natlinkmain...
 from vocola2.exec.vcl2py.main import main_routine     # main.main_routine  compile function
 import __init__
 
@@ -58,9 +58,9 @@ thisDir = os.path.split(__file__)[0]
 ##########################################################################
 
 try:
-    from natlink import natlinkstatus
-    from natlink import loader  
-    from natlink import config    ## only needed when debugging probably
+    from natlinkcore import natlinkstatus
+    from natlinkcore import loader  
+    from natlinkcore import config    ## only needed when debugging probably
     Quintijn_installer = True
     status             = natlinkstatus.NatlinkStatus()
 
@@ -77,10 +77,18 @@ try:
         VocolaGrammarsDirectory = status.getVocolaGrammarsDirectory()
         VocolaUserDirectory = status.getVocolaUserDirectory()
         VocolaDirectory = status.getVocolaDirectory()
+        if not os.path.isdir(VocolaUserDirectory):
+            raise OSError(f'VocolaUserDirectory does not exist, please create: "{VocolaUserDirectory}, or re-configure Natlink.')
+        if not os.path.isdir(VocolaGrammarsDirectory):
+            oneup = os.path.abspath(os.path.join(VocolaUserDirectory, '..'))
+            if not os.path.isdir(oneup):
+                raise OSError(f'_vocola_main: cannot create VocolaGrammarsDirectory "{VocolaGrammarsDirectory}", because the\n\tdirectory above, "{oneup}", is not a directory')
+            os.mkdir(VocolaGrammarsDirectory)
+            if not os.path.isdir(VocolaGrammarsDirectory):
+                raise OSError(f'Could not create the "VocolaGrammarsDirecory": "{VocolaGrammarsDirectory}"')
+            
     else:
-        VocolaGrammarsDirectory = ""
-        VocolaUserDirectory = ""
-        VocolaDirectory = ""
+        raise OSError(f'Vocola is not Enabled, but this directory "{thisDir}" seems to be in the "directories" section of Natlink, please check your configuration.')
         
     # print('VocolaEnabled: %s'% VocolaEnabled)
     VocolaUserLanguageDirectory = VocolaUserDirectory
@@ -89,7 +97,9 @@ try:
         print(f'    language: "{language}"')
         if status.getVocolaTakesLanguages():
             VocolaUserLanguageDirectory = os.path.join(VocolaUserDirectory, language)
-            print(f'    VocolaUserLanguageDirectory: "{VocolaUserLanguageDirectory}"')
+            if not os.path.exists(VocolaUserLanguageDirectory):
+                os.mkdir(VocolaUserLanguageDirectory)
+                
     ## perform init actions: exclude for testing purposes QH
     # natlinkvocolastartup.start()
 except ImportError:
@@ -132,7 +142,7 @@ def checkExtensionsFolderContents(original, actual):
     
     """
     if not os.path.isdir(actual):
-        if os.path.exist(actual):
+        if os.path.exists(actual):
             raise OSError(f'extensionsfolder exists, but is not a directory: "{actual}"')
         os.mkdir(actual)
     if not os.path.isdir(actual):
@@ -253,13 +263,13 @@ class ThisGrammar(natlinkutils.GrammarBase):
     """
     elif language != 'enx':
         print("""\n\n
-Vocola Warning: no language "%s" translations for the built-in Vocola
+Vocola Warning: no language "{language}" translations for the built-in Vocola
 commands (e.g., commands to load voice commands) are currently
 available; consider helping translate them -- inquire on
 https://www.knowbrainer.com/forums/forum/categories.cfm?catid=25.  For
 now the English versions, like "Edit Commands" and "Edit Global
 Commands" are activated.
-""" % language, file=sys.stderr)
+""", file=sys.stderr)
 
     def initialize(self):
         if 'COMPUTERNAME' in os.environ:
@@ -439,9 +449,8 @@ Commands" are activated.
         if not path:
             path = commandFolder + '\\' + file
 
-            new = open(path, 'w')
-            new.write('# ' + comment + '\n\n')
-            new.close()
+            with open(path, 'w', encoding='ascii') as fp:
+                fp.write(f'# {comment} \n\n')
 
         #
         # Natlink/DNS bug causes os.startfile or wpi32api.ShellExecute
@@ -490,6 +499,7 @@ def compile_Vocola(inputFileOrFolder, force=None):
 
     arguments += ["-suffix", "_vcl"]
     if force: arguments += ["-f"]
+    print(f'compile_Vocola, inputFileOrFolder: "{inputFileOrFolder}"')
     arguments += [inputFileOrFolder, VocolaGrammarsDirectory]
     # print(f'_vocola_main calls vcl2py.py, grammars go to folder: {VocolaGrammarsDirectory}')
     # print(f'calling executable: {executable}')
