@@ -584,7 +584,7 @@ def inline_a_term(unnamed):
 
     # Find the array index of the first non-optional term
     index = 0
-    while (index < terms) and (terms[index]["OPTIONAL"] or terms[index]["TYPE"] == "dictation"): index += 1
+    while (index < len(terms)) and (terms[index]["OPTIONAL"] or terms[index]["TYPE"] == "dictation"): index += 1
 
     type = terms[index]["TYPE"]
     number = terms[index]["NUMBER"]
@@ -664,7 +664,7 @@ def emit_file_header():
     print("#pylint:disable=W0401, W0614, E1101", file=OUT)
     print('''
 import natlink
-from natlink import natlinkutils
+from natlinkcore import natlinkutils
 from vocola2.VocolaUtils import *
 
 
